@@ -15,6 +15,7 @@ from types import GeneratorType
 import re
 
 from testfixtures import not_there, singleton
+from testfixtures.compat import PY_311_PLUS
 from testfixtures.resolve import resolve
 from testfixtures.utils import indent
 from testfixtures.mock import parent_name, mock_call
@@ -132,13 +133,13 @@ def compare_object(
     y_attrs = _extract_attrs(y, _attrs_to_ignore(context, ignore_attributes, y))
     if x_attrs is None or y_attrs is None or not (x_attrs and y_attrs):
         return compare_simple(x, y, context)
-    if context.strict or context.ignore_eq or x_attrs != y_attrs:
+    if not context.simple_equals(x_attrs, y_attrs):
         return _compare_mapping(x_attrs, y_attrs, context, x,
                                 'attributes ', '.%s')
 
 
 def compare_exception(
-        x: Exception, y: Exception, context: 'CompareContext'
+        x: BaseException, y: BaseException, context: 'CompareContext'
 ) -> Optional[str]:
     """
     Compare the two supplied exceptions based on their message, type and
@@ -206,7 +207,7 @@ def compare_generator(x: Generator, y: Generator, context: 'CompareContext') ->
     x = tuple(x)
     y = tuple(y)
 
-    if not context.ignore_eq and x == y:
+    if context.simple_equals(x, y):
         return
 
     return compare_sequence(x, y, context)
@@ -489,7 +490,25 @@ _registry: Registry = {
     Path: compare_path,
     datetime: compare_with_fold,
     time: compare_with_fold,
-    }
+}
+
+if PY_311_PLUS:
+
+    def compare_exception_group(
+        x: BaseExceptionGroup, y: BaseExceptionGroup, context: 'CompareContext'
+    ) -> Optional[str]:
+        """
+        Compare the two supplied exception groups
+        """
+
+        x_msg, x_excs = x.args
+        y_msg, y_excs = y.args
+        msg_different = context.different(x_msg, y_msg, 'msg')
+        excs_different = context.different(x_excs, y_excs, 'excs')
+        if msg_different or excs_different:
+            return 'exception group not as expected:'
+
+    _registry[BaseExceptionGroup] = compare_exception_group
 
 
 def register(type_: type, comparer: Comparer):
@@ -631,6 +650,9 @@ class CompareContext:
             self._seen[id_] = breadcrumb
             return obj
 
+    def simple_equals(self, x: Any, y: Any) -> bool:
+        return not (self.strict or self.ignore_eq) and x == y
+
     def different(self, x: Any, y: Any, breadcrumb: str) -> Union[bool, Optional[str]]:
 
         x = self._break_loops(x, breadcrumb)
